summaryrefslogtreecommitdiff
path: root/src/cmd/gc/sinit.c
diff options
context:
space:
mode:
authorRob Pike <r@golang.org>2009-08-25 15:54:25 -0700
committerRob Pike <r@golang.org>2009-08-25 15:54:25 -0700
commita399c977c938c97082e61a01725cfe6d9db34867 (patch)
treef3913b178bfbc73429efbd39df31e880769d1c3d /src/cmd/gc/sinit.c
parent5475005371c17da4fb7ef23ccd8ee050aa91807b (diff)
downloadgolang-a399c977c938c97082e61a01725cfe6d9db34867.tar.gz
rename runtime internals to have modern names (array->slice etc)
R=rsc DELTA=444 (179 added, 177 deleted, 88 changed) OCL=33847 CL=33849
Diffstat (limited to 'src/cmd/gc/sinit.c')
-rw-r--r--src/cmd/gc/sinit.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/cmd/gc/sinit.c b/src/cmd/gc/sinit.c
index 4b46f7c7c..84e844c27 100644
--- a/src/cmd/gc/sinit.c
+++ b/src/cmd/gc/sinit.c
@@ -146,8 +146,8 @@ slicerewrite(Node *n)
while(n->op == OCONVNOP)
n = n->left;
- // call to newarray - find nel argument
- nel = findarg(n, "nel", "newarray");
+ // call to makeslice - find nel argument
+ nel = findarg(n, "nel", "makeslice");
if(nel == N || !isslice(n->type))
goto no;
@@ -177,8 +177,8 @@ maprewrite(Node *n)
Type *ta, *tb;
Node *a;
- // call to newarray - find nel argument
- nel = findarg(n, "hint", "newmap");
+ // call to makemap - find len argument
+ nel = findarg(n, "hint", "makemap");
if(nel == N)
goto no;
ta = n->type;
@@ -371,7 +371,7 @@ sli:
if(r->op != OAS && r->op != OEMPTY)
continue;
// first usage "nam = (newarray CALL args)"
if(r->right != N && sametmp(r->left, nam)) {
w = slicerewrite(r->right);
if(w == N)
@@ -427,7 +427,7 @@ return;
if(r->op != OAS && r->op != OEMPTY)
continue;
// first usage "nam = (newmap CALL args)"
if(r->right != N && sametmp(r->left, nam)) {
w = maprewrite(r->right);
if(w == N)
@@ -371,7 +371,7 @@ sli:
if(r->op != OAS && r->op != OEMPTY)
continue;
- // first usage "nam = (newarray CALL args)"
+ // first usage "nam = (makeslice CALL args)"
if(r->right != N && sametmp(r->left, nam)) {
w = slicerewrite(r->right);
@@ -427,7 +427,7 @@ return;
if(r->op != OAS && r->op != OEMPTY)
continue;
- // first usage "nam = (newmap CALL args)"
+ // first usage "nam = (makemap CALL args)"
if(r->right != N && sametmp(r->left, nam)) {
w = maprewrite(r->right);